import React from 'react'
import styled from 'styled-components'
import { Link } from 'react-router-dom'
import { withHandlers } from 'recompose'
import { th } from '@pubsweet/ui-toolkit'
import { Action, Icon } from '@pubsweet/ui'

import { paddingHelper, marginHelper } from './styledHelpers'

const ActionLink = ({
  to,
  icon,
  size,
  onClick,
  disabled,
  children,
  renderLink,
  iconSize = 2,
  iconPosition = 'left',
  ...rest
}) => (
  <Root {...rest} to={to}>
    {icon &&
      iconPosition === 'left' && (
        <Icon onClick={onClick} secondary={to} size={iconSize} warning={!to}>
          {icon}
        </Icon>
      )}
    {renderLink()}
    {icon &&
      iconPosition === 'right' && (
        <Icon onClick={onClick} secondary={to} size={iconSize} warning={!to}>
          {icon}
        </Icon>
      )}
  </Root>
)

export default withHandlers({
  renderLink: ({ to, internal, disabled, onClick, size, children }) => () => {
    if (to && !internal) {
      return (
        <ExternalLink href={to} target="_blank">
          {children}
        </ExternalLink>
      )
    }

    if (to && internal) {
      return <CustomLink to={to}>{children}</CustomLink>
    }
    return (
      <Action disabled={disabled} onClick={onClick} size={size}>
        {children}
      </Action>
    )
  },
})(ActionLink)

// #region styles
const ExternalLink = styled.a`
  color: ${th('colorSecondary')};
  font-family: ${th('fontReading')};
  text-decoration: underline;

  &:hover {
    color: ${th('colorSecondary')};
    font-family: ${th('fontReading')};
    text-decoration: underline;
  }
`
const CustomLink = ExternalLink.withComponent(Link)

const Root = styled.div`
  align-items: center;
  display: ${props => (props.to ? 'inline-flex' : 'flex')};

  ${marginHelper};
  ${paddingHelper};

  height: ${props => (props.height ? `${props.height}px` : 'max-content')};
  width: max-content;

  & span {
    padding-top: 5px;
  }
`
// #endregion
