const { services } = require('pubsweet-component-helper-service')
const { token } = require('pubsweet-server/src/authentication')

module.exports = models => async (req, res) => {
  const { password, newPassword } = req.body
  if (!services.checkForUndefinedParams(password, newPassword))
    return res.status(400).json({ error: 'Missing required params.' })

  if (newPassword.length < 7)
    return res
      .status(400)
      .json({ error: 'Password needs to be at least 7 characters long.' })

  let user
  try {
    user = await models.User.find(req.user)

    if (!await user.validPassword(password)) {
      return res.status(400).json({ error: 'Wrong username or password.' })
    }
    user.password = newPassword
    user = await user.save()

    return res.status(200).json({
      ...user,
      token: token.create(user),
    })
  } catch (e) {
    const notFoundError = await services.handleNotFoundError(e, 'User')
    return res.status(notFoundError.status).json({
      error: notFoundError.message,
    })
  }
}
